@@ -1,6 +1,7 @@
 from datetime import datetime
 from taiga.requestmaker import RequestMaker
-from taiga.models import User, Point, UserStoryStatus, Severity, Project, Projects
+from taiga.models import User, Point, UserStoryStatus
+from taiga.models import Severity, Role, Project, Projects
 import unittest
 from mock import patch
 from taiga import TaigaAPI
@@ -30,8 +31,6 @@ class TestProjects(unittest.TestCase):
         projects = api.projects.list()
         self.assertEqual(projects[0].description, 'test 1 on real taiga')
         self.assertEqual(len(projects), 1)
-        self.assertEqual(len(projects[0].users), 1)
-        self.assertTrue(isinstance(projects[0].users[0], User))
 
     @patch('taiga.requestmaker.RequestMaker.get')
     def test_stats(self, mock_requestmaker_get):
@@ -114,6 +113,20 @@ class TestProjects(unittest.TestCase):
         project.list_severities()
         mock_list_severities.assert_called_with(project=1)
 
+    @patch('taiga.models.Roles.create')
+    def test_add_role(self, mock_new_role):
+        rm = RequestMaker('/api/v1', 'fakehost', 'faketoken')
+        project = Project(rm, id=1)
+        project.add_role('Role 1')
+        mock_new_role.assert_called_with(1, 'Role 1')
+
+    @patch('taiga.models.Roles.list')
+    def test_list_roles(self, mock_list_roles):
+        rm = RequestMaker('/api/v1', 'fakehost', 'faketoken')
+        project = Project(rm, id=1)
+        project.list_roles()
+        mock_list_roles.assert_called_with(project=1)
+
     @patch('taiga.models.models.IssueTypes.create')
     def test_add_issue_type(self, mock_new_issue_type):
         rm = RequestMaker('/api/v1', 'fakehost', 'faketoken')
@@ -283,3 +296,18 @@ class TestProjects(unittest.TestCase):
         project = Project(rm, id=1)
         project.list_user_story_attributes()
         mock_list_us_attr.assert_called_with(project=1)
+
+    @patch('taiga.models.Memberships.create')
+    def test_add_membership(self, mock_new_membership):
+        rm = RequestMaker('/api/v1', 'fakehost', 'faketoken')
+        project = Project(rm, id=1)
+        project.add_membership('test@example.com', 1)
+        mock_new_membership.assert_called_with(1, 'test@example.com', 1)
+
+    @patch('taiga.models.Memberships.list')
+    def test_list_membership(self, mock_list_memberships):
+        rm = RequestMaker('/api/v1', 'fakehost', 'faketoken')
+        project = Project(rm, id=1)
+        project.list_memberships()
+        mock_list_memberships.assert_called_with(project=1)
+
